Utilization — PBxplore 1.3.5 documentation

# Utilization

There is 2 ways to use PBxplore:
  - command-line scripts
  - API

## Command-line scripts

PBxplore is bundle with a suite of command-line tools. Once installed, they should be available in your `$PATH`. Here the list:

- PBassign assign Protein Blocks (PBs) from a set of protein structures.
- PBcount computes the frequency of PBs at each position along the amino acid sequence.
- PBstat generates frequency and logo plots, and estimates the Neq.

## API

PBxplore is also a python library and provides an API to interfacing with Python applications. You will find here a list of notebooks to help you use the API.